.. _jwst_data_files:

JWST data files
===============

These data files are needed for calculations involving JWST bandpasses.
They are being distributed by JWST Exposure Time Calculator; please see
`Pandeia Reference Data <https://jwst-docs.stsci.edu/jwst-exposure-time-calculator-overview/jwst-etc-pandeia-engine-tutorial/pandeia-reference-data>`_
for more information.
